@@ -14,17 +14,12 @@ namespace rime {
 class Candidate {
  public:
   Candidate() = default;
-  Candidate(const string& type,
-            size_t start,
-            size_t end,
-            double quality = 0.)
+  Candidate(const string& type, size_t start, size_t end, double quality = 0.)
       : type_(type), start_(start), end_(end), quality_(quality) {}
   virtual ~Candidate() = default;
 
-  static an<Candidate>
-  GetGenuineCandidate(const an<Candidate>& cand);
-  static vector<of<Candidate>>
-  GetGenuineCandidates(const an<Candidate>& cand);
+  static an<Candidate> GetGenuineCandidate(const an<Candidate>& cand);
+  static vector<of<Candidate>> GetGenuineCandidates(const an<Candidate>& cand);
 
   // recognized by translators in learning phase
   const string& type() const { return type_; }
@@ -55,7 +50,7 @@ class Candidate {
 using CandidateQueue = list<of<Candidate>>;
 using CandidateList = vector<of<Candidate>>;
 
-// useful implimentations
+// useful implementations
 
 class SimpleCandidate : public Candidate {
  public:
@@ -67,7 +62,9 @@ class SimpleCandidate : public Candidate {
                   const string& comment = string(),
                   const string& preedit = string())
       : Candidate(type, start, end),
-      text_(text), comment_(comment), preedit_(preedit) {}
+        text_(text),
+        comment_(comment),
+        preedit_(preedit) {}
 
   const string& text() const { return text_; }
   string comment() const { return comment_; }
@@ -91,18 +88,16 @@ class ShadowCandidate : public Candidate {
                   const string& comment = string(),
                   const bool inherit_comment = true)
       : Candidate(type, item->start(), item->end(), item->quality()),
-        text_(text), comment_(comment),
-        item_(item), inherit_comment_(inherit_comment) {}
+        text_(text),
+        comment_(comment),
+        item_(item),
+        inherit_comment_(inherit_comment) {}
 
-  const string& text() const {
-    return text_.empty() ? item_->text() : text_;
-  }
+  const string& text() const { return text_.empty() ? item_->text() : text_; }
   string comment() const {
     return inherit_comment_ && comment_.empty() ? item_->comment() : comment_;
   }
-  string preedit() const {
-    return item_->preedit();
-  }
+  string preedit() const { return item_->preedit(); }
 
   const an<Candidate>& item() const { return item_; }
 
@@ -120,17 +115,17 @@ class UniquifiedCandidate : public Candidate {
                       const string& text = string(),
                       const string& comment = string())
       : Candidate(type, item->start(), item->end(), item->quality()),
-        text_(text), comment_(comment) {
+        text_(text),
+        comment_(comment) {
     Append(item);
   }
 
   const string& text() const {
-    return text_.empty() && !items_.empty() ?
-        items_.front()->text() : text_;
+    return text_.empty() && !items_.empty() ? items_.front()->text() : text_;
   }
   string comment() const {
-    return comment_.empty() && !items_.empty() ?
-        items_.front()->comment() : comment_;
+    return comment_.empty() && !items_.empty() ? items_.front()->comment()
+                                               : comment_;
   }
   string preedit() const {
     return !items_.empty() ? items_.front()->preedit() : string();
