@@ -30,6 +30,7 @@
 #endif
 
 #ifdef RIME_ENABLE_LOGGING
+#define GLOG_NO_ABBREVIATED_SEVERITIES
 #include <glog/logging.h>
 #else
 #include "no_logging.h"
@@ -42,15 +43,16 @@
 
 namespace rime {
 
+using boost::optional;
 using std::function;
 using std::list;
 using std::make_pair;
+using std::make_unique;
 using std::map;
 using std::pair;
 using std::set;
 using std::string;
 using std::vector;
-using boost::optional;
 
 template <class Key, class T>
 using hash_map = std::unordered_map<Key, T>;
@@ -85,8 +87,8 @@ inline an<T> New(Args&&... args) {
 using boost::signals2::connection;
 using boost::signals2::signal;
 #else
-using boost::signals::connection;
 using boost::signal;
+using boost::signals::connection;
 #endif
 
 }  // namespace rime
