@@ -11,24 +11,21 @@
 
 namespace rime {
 
-static const ResourceType kCompiledConfig = {
-  "compiled_config", "", ".yaml"
-};
+static const ResourceType kCompiledConfig = {"compiled_config", "", ".yaml"};
 
 SaveOutputPlugin::SaveOutputPlugin()
     : resource_resolver_(
-          Service::instance().CreateStagingResourceResolver(kCompiledConfig)) {
-}
+          Service::instance().CreateStagingResourceResolver(kCompiledConfig)) {}
 
 SaveOutputPlugin::~SaveOutputPlugin() {}
 
-bool SaveOutputPlugin::ReviewCompileOutput(
-    ConfigCompiler* compiler, an<ConfigResource> resource) {
+bool SaveOutputPlugin::ReviewCompileOutput(ConfigCompiler* compiler,
+                                           an<ConfigResource> resource) {
   return true;
 }
 
-bool SaveOutputPlugin::ReviewLinkOutput(
-    ConfigCompiler* compiler, an<ConfigResource> resource) {
+bool SaveOutputPlugin::ReviewLinkOutput(ConfigCompiler* compiler,
+                                        an<ConfigResource> resource) {
   auto file_path = resource_resolver_->ResolvePath(resource->resource_id);
   return resource->data->SaveToFile(file_path.string());
 }
