@@ -4,20 +4,24 @@
 //
 // 2011-11-27 GONG Chen <chen.sst@gmail.com>
 //
+#include <algorithm>
 #include <fstream>
+#include <utility>
 #include <boost/algorithm/string.hpp>
 #include <boost/lexical_cast.hpp>
+#include <rime/algo/strings.h>
 #include <rime/dict/dict_settings.h>
 #include <rime/dict/entry_collector.h>
 #include <rime/dict/preset_vocabulary.h>
 
 namespace rime {
 
-EntryCollector::EntryCollector() {
-}
+EntryCollector::EntryCollector() {}
 
-EntryCollector::~EntryCollector() {
-}
+EntryCollector::EntryCollector(Syllabary&& fixed_syllabary)
+    : syllabary(std::move(fixed_syllabary)), build_syllabary(false) {}
+
+EntryCollector::~EntryCollector() {}
 
 void EntryCollector::Configure(DictSettings* settings) {
   if (settings->use_preset_vocabulary()) {
@@ -26,8 +30,7 @@ void EntryCollector::Configure(DictSettings* settings) {
 
   if (settings->use_rule_based_encoder()) {
     encoder.reset(new TableEncoder(this));
-  }
-  else {
+  } else {
     encoder.reset(new ScriptEncoder(this));
   }
   encoder->LoadSettings(settings);
@@ -75,7 +78,8 @@ void EntryCollector::Collect(const string& dict_file) {
   while (getline(fin, line)) {
     boost::algorithm::trim_right(line);
     // skip empty lines and comments
-    if (line.empty()) continue;
+    if (line.empty())
+      continue;
     if (enable_comment && line[0] == '#') {
       if (line == "# no comment") {
         // a "# no comment" line disables further comments
@@ -84,9 +88,7 @@ void EntryCollector::Collect(const string& dict_file) {
       continue;
     }
     // read a dict entry
-    vector<string> row;
-    boost::algorithm::split(row, line,
-                            boost::algorithm::is_any_of("\t"));
+    auto row = strings::split(line, "\t");
     int num_columns = static_cast<int>(row.size());
     if (num_columns <= text_column || row[text_column].empty()) {
       LOG(WARNING) << "Missing entry text at #" << num_entries << ".";
@@ -96,21 +98,20 @@ void EntryCollector::Collect(const string& dict_file) {
     string code_str;
     string weight_str;
     string stem_str;
-    if (code_column != -1 &&
-        num_columns > code_column && !row[code_column].empty())
+    if (code_column != -1 && num_columns > code_column &&
+        !row[code_column].empty())
       code_str = row[code_column];
-    if (weight_column != -1 &&
-        num_columns > weight_column && !row[weight_column].empty())
+    if (weight_column != -1 && num_columns > weight_column &&
+        !row[weight_column].empty())
       weight_str = row[weight_column];
-    if (stem_column != -1 &&
-        num_columns > stem_column && !row[stem_column].empty())
+    if (stem_column != -1 && num_columns > stem_column &&
+        !row[stem_column].empty())
       stem_str = row[stem_column];
     // collect entry
     collection.insert(word);
     if (!code_str.empty()) {
       CreateEntry(word, code_str, weight_str);
-    }
-    else {
+    } else {
       encode_queue.push({word, weight_str});
     }
     if (!stem_str.empty() && !code_str.empty()) {
@@ -146,72 +147,82 @@ void EntryCollector::Finish() {
       }
     }
   }
+  decltype(collection)().swap(collection);
+  decltype(words)().swap(words);
+  decltype(total_weight)().swap(total_weight);
   LOG(INFO) << "Pass 3: total " << num_entries << " entries collected.";
 }
 
-void EntryCollector::CreateEntry(const string &word,
-                                 const string &code_str,
-                                 const string &weight_str) {
-  RawDictEntry e;
-  e.raw_code.FromString(code_str);
-  e.text = word;
-  e.weight = 0.0;
+void EntryCollector::CreateEntry(const string& word,
+                                 const string& code_str,
+                                 const string& weight_str) {
+  an<RawDictEntry> e = New<RawDictEntry>();
+  e->raw_code.FromString(code_str);
+  e->text = word;
+  e->weight = 0.0;
   bool scaled = boost::ends_with(weight_str, "%");
   if ((weight_str.empty() || scaled) && preset_vocabulary) {
-    preset_vocabulary->GetWeightForEntry(e.text, &e.weight);
+    preset_vocabulary->GetWeightForEntry(e->text, &e->weight);
   }
   if (scaled) {
     double percentage = 100.0;
     try {
-      percentage = boost::lexical_cast<double>(
-          weight_str.substr(0, weight_str.length() - 1));
-    }
-    catch (...) {
+      percentage = std::stod(weight_str.substr(0, weight_str.length() - 1));
+    } catch (...) {
       LOG(WARNING) << "invalid entry definition at #" << num_entries << ".";
       percentage = 100.0;
     }
-    e.weight *= percentage / 100.0;
-  }
-  else if (!weight_str.empty()) {  // absolute weight
+    e->weight *= percentage / 100.0;
+  } else if (!weight_str.empty()) {  // absolute weight
     try {
-      e.weight = boost::lexical_cast<double>(weight_str);
-    }
-    catch (...) {
+      e->weight = std::stod(weight_str);
+    } catch (...) {
       LOG(WARNING) << "invalid entry definition at #" << num_entries << ".";
-      e.weight = 0.0;
+      e->weight = 0.0;
     }
   }
-  // learn new syllables
-  for (const string& s : e.raw_code) {
-    if (syllabary.find(s) == syllabary.end())
-      syllabary.insert(s);
+  // learn new syllables, or check if syllables are in the fixed syllabary.
+  for (const string& s : e->raw_code) {
+    if (syllabary.find(s) == syllabary.end()) {
+      if (build_syllabary) {
+        syllabary.insert(s);
+      } else {
+        LOG(ERROR) << "dropping entry '" << e->text
+                   << "' with invalid syllable: " << s;
+        return;
+      }
+    }
   }
   // learn new word
-  bool is_word = (e.raw_code.size() == 1);
+  bool is_word = (e->raw_code.size() == 1);
   if (is_word) {
-    if (words[e.text].find(code_str) != words[e.text].end()) {
-      LOG(WARNING) << "duplicate word definition '"
-                   << e.text << "': [" << code_str << "].";
+    auto& weights = words[e->text];
+    if (std::find_if(weights.begin(), weights.end(), [&](const auto& p) {
+          return p.first == code_str;
+        }) != weights.end()) {
+      LOG(WARNING) << "duplicate word definition '" << e->text << "': ["
+                   << code_str << "].";
       return;
     }
-    words[e.text][code_str] += e.weight;
-    total_weight[e.text] += e.weight;
+    weights.push_back(std::make_pair(code_str, e->weight));
+    total_weight[e->text] += e->weight;
   }
-  entries.push_back(e);
+  entries.emplace_back(std::move(e));
   ++num_entries;
 }
 
-bool EntryCollector::TranslateWord(const string& word,
-                                   vector<string>* result) {
-  ReverseLookupTable::const_iterator s = stems.find(word);
+bool EntryCollector::TranslateWord(const string& word, vector<string>* result) {
+  const auto& s = stems.find(word);
   if (s != stems.end()) {
     for (const string& stem : s->second) {
       result->push_back(stem);
     }
     return true;
   }
-  WordMap::const_iterator w = words.find(word);
+  const auto& w = words.find(word);
   if (w != words.end()) {
+    std::sort(w->second.begin(), w->second.end(),
+              [](const auto& a, const auto& b) { return a.first < b.first; });
     for (const auto& v : w->second) {
       const double kMinimalWeight = 0.05;  // 5%
       double min_weight = total_weight[word] * kMinimalWeight;
@@ -231,10 +242,9 @@ void EntryCollector::Dump(const string& file_name) const {
     out << "# - " << syllable << std::endl;
   }
   out << std::endl;
-  for (const RawDictEntry& e : entries) {
-    out << e.text << '\t'
-        << e.raw_code.ToString() << '\t'
-        << e.weight << std::endl;
+  for (const auto& e : entries) {
+    out << e->text << '\t' << e->raw_code.ToString() << '\t' << e->weight
+        << std::endl;
   }
   out.close();
 }
