@@ -23,8 +23,7 @@ class PresetVocabulary {
   // traversing
   void Reset();
   bool GetNextEntry(string* key, string* value);
-  bool IsQualifiedPhrase(const string& phrase,
-                         const string& weight_str);
+  bool IsQualifiedPhrase(const string& phrase, const string& weight_str);
 
   void set_max_phrase_length(int length) { max_phrase_length_ = length; }
   void set_min_phrase_weight(double weight) { min_phrase_weight_ = weight; }
