@@ -21,48 +21,13 @@ const int kTableFormatLowestCompatible = 4.0;
 const char kTableFormatPrefix[] = "Rime::Table/";
 const size_t kTableFormatPrefixLen = sizeof(kTableFormatPrefix) - 1;
 
-class TableQuery {
- public:
-  TableQuery(table::Index* index) : lv1_index_(index) {
-    Reset();
-  }
-
-  TableAccessor Access(SyllableId syllable_id,
-                       double credibility = 0.0) const;
-
-  // down to next level
-  bool Advance(SyllableId syllable_id, double credibility = 0.0);
-
-  // up one level
-  bool Backdate();
-
-  // back to root
-  void Reset();
-
-  size_t level() const { return level_; }
-
- protected:
-  size_t level_ = 0;
-  Code index_code_;
-  vector<double> credibility_;
-
- private:
-  bool Walk(SyllableId syllable_id);
-
-  table::HeadIndex* lv1_index_ = nullptr;
-  table::TrunkIndex* lv2_index_ = nullptr;
-  table::TrunkIndex* lv3_index_ = nullptr;
-  table::TailIndex* lv4_index_ = nullptr;
-};
-
 TableAccessor::TableAccessor(const Code& index_code,
                              const List<table::Entry>* list,
                              double credibility)
     : index_code_(index_code),
       entries_(list->at.get()),
       size_(list->size),
-      credibility_(credibility) {
-}
+      credibility_(credibility) {}
 
 TableAccessor::TableAccessor(const Code& index_code,
                              const Array<table::Entry>* array,
@@ -70,8 +35,7 @@ TableAccessor::TableAccessor(const Code& index_code,
     : index_code_(index_code),
       entries_(array->at),
       size_(array->size),
-      credibility_(credibility) {
-}
+      credibility_(credibility) {}
 
 TableAccessor::TableAccessor(const Code& index_code,
                              const table::TailIndex* code_map,
@@ -79,8 +43,7 @@ TableAccessor::TableAccessor(const Code& index_code,
     : index_code_(index_code),
       long_entries_(code_map->at),
       size_(code_map->size),
-      credibility_(credibility) {
-}
+      credibility_(credibility) {}
 
 bool TableAccessor::exhausted() const {
   if (entries_ || long_entries_) {
@@ -174,16 +137,14 @@ static table::TrunkIndexNode* find_node(table::TrunkIndexNode* first,
 
 bool TableQuery::Walk(SyllableId syllable_id) {
   if (level_ == 0) {
-    if (!lv1_index_ ||
-        syllable_id < 0 ||
+    if (!lv1_index_ || syllable_id < 0 ||
         syllable_id >= static_cast<SyllableId>(lv1_index_->size))
       return false;
     auto node = &lv1_index_->at[syllable_id];
     if (!node->next_level)
       return false;
     lv2_index_ = &node->next_level->trunk();
-  }
-  else if (level_ == 1) {
+  } else if (level_ == 1) {
     if (!lv2_index_)
       return false;
     auto node = find_node(lv2_index_->begin(), lv2_index_->end(), syllable_id);
@@ -192,8 +153,7 @@ bool TableQuery::Walk(SyllableId syllable_id) {
     if (!node->next_level)
       return false;
     lv3_index_ = &node->next_level->trunk();
-  }
-  else if (level_ == 2) {
+  } else if (level_ == 2) {
     if (!lv3_index_)
       return false;
     auto node = find_node(lv3_index_->begin(), lv3_index_->end(), syllable_id);
@@ -202,8 +162,7 @@ bool TableQuery::Walk(SyllableId syllable_id) {
     if (!node->next_level)
       return false;
     lv4_index_ = &node->next_level->tail();
-  }
-  else {
+  } else {
     return false;
   }
   return true;
@@ -218,25 +177,22 @@ TableAccessor TableQuery::Access(SyllableId syllable_id,
                                  double credibility) const {
   credibility += credibility_.back();
   if (level_ == 0) {
-    if (!lv1_index_ ||
-        syllable_id < 0 ||
+    if (!lv1_index_ || syllable_id < 0 ||
         syllable_id >= static_cast<SyllableId>(lv1_index_->size))
       return TableAccessor();
     auto node = &lv1_index_->at[syllable_id];
-    return TableAccessor(add_syllable(index_code_, syllable_id),
-                         &node->entries, credibility);
-  }
-  else if (level_ == 1 || level_ == 2) {
+    return TableAccessor(add_syllable(index_code_, syllable_id), &node->entries,
+                         credibility);
+  } else if (level_ == 1 || level_ == 2) {
     auto index = (level_ == 1) ? lv2_index_ : lv3_index_;
     if (!index)
       return TableAccessor();
     auto node = find_node(index->begin(), index->end(), syllable_id);
     if (node == index->end())
       return TableAccessor();
-    return TableAccessor(add_syllable(index_code_, syllable_id),
-                         &node->entries, credibility);
-  }
-  else if (level_ == 3) {
+    return TableAccessor(add_syllable(index_code_, syllable_id), &node->entries,
+                         credibility);
+  } else if (level_ == 3) {
     if (!lv4_index_)
       return TableAccessor();
     return TableAccessor(index_code_, lv4_index_, credibility);
@@ -257,7 +213,8 @@ string Table::GetString(const table::StringType& x) {
   return string_table_->GetString(x.str_id());
 }
 
-bool Table::AddString(const string& src, table::StringType* dest,
+bool Table::AddString(const string& src,
+                      table::StringType* dest,
                       double weight) {
   string_table_builder_->Add(src, weight, &dest->str_id());
   return true;
@@ -289,11 +246,9 @@ bool Table::OnLoad() {
   return true;
 }
 
-Table::Table(const string& file_name) : MappedFile(file_name) {
-}
+Table::Table(const string& file_name) : MappedFile(file_name) {}
 
-Table::~Table() {
-}
+Table::~Table() {}
 
 bool Table::Load() {
   LOG(INFO) << "loading table file: " << file_name();
@@ -356,11 +311,14 @@ uint32_t Table::dict_file_checksum() const {
   return metadata_ ? metadata_->dict_file_checksum : 0;
 }
 
-bool Table::Build(const Syllabary& syllabary, const Vocabulary& vocabulary,
-                  size_t num_entries, uint32_t dict_file_checksum) {
+bool Table::Build(const Syllabary& syllabary,
+                  const Vocabulary& vocabulary,
+                  size_t num_entries,
+                  uint32_t dict_file_checksum) {
   const size_t kReservedSize = 4096;
   size_t num_syllables = syllabary.size();
-  size_t estimated_file_size = kReservedSize + 32 * num_syllables + 64 * num_entries;
+  size_t estimated_file_size =
+      kReservedSize + 32 * num_syllables + 64 * num_entries;
   LOG(INFO) << "building table.";
   LOG(INFO) << "num syllables: " << num_syllables;
   LOG(INFO) << "num entries: " << num_entries;
@@ -389,8 +347,7 @@ bool Table::Build(const Syllabary& syllabary, const Vocabulary& vocabulary,
   if (!syllabary_) {
     LOG(ERROR) << "Error creating syllabary.";
     return false;
-  }
-  else {
+  } else {
     size_t i = 0;
     for (const string& syllable : syllabary) {
       AddString(syllable, &syllabary_->at[i++], 0.0);
@@ -418,8 +375,8 @@ bool Table::Build(const Syllabary& syllabary, const Vocabulary& vocabulary,
 
 table::Index* Table::BuildIndex(const Vocabulary& vocabulary,
                                 size_t num_syllables) {
-  return reinterpret_cast<table::Index*>(BuildHeadIndex(vocabulary,
-                                                        num_syllables));
+  return reinterpret_cast<table::Index*>(
+      BuildHeadIndex(vocabulary, num_syllables));
 }
 
 table::HeadIndex* Table::BuildHeadIndex(const Vocabulary& vocabulary,
@@ -433,7 +390,7 @@ table::HeadIndex* Table::BuildHeadIndex(const Vocabulary& vocabulary,
     auto& node(index->at[syllable_id]);
     const auto& entries(v.second.entries);
     if (!BuildEntryList(entries, &node.entries)) {
-        return NULL;
+      return NULL;
     }
     if (v.second.next_level) {
       Code code;
@@ -461,7 +418,7 @@ table::TrunkIndex* Table::BuildTrunkIndex(const Code& prefix,
     node.key = syllable_id;
     const auto& entries(v.second.entries);
     if (!BuildEntryList(entries, &node.entries)) {
-        return NULL;
+      return NULL;
     }
     if (v.second.next_level) {
       Code code(prefix);
@@ -473,8 +430,7 @@ table::TrunkIndex* Table::BuildTrunkIndex(const Code& prefix,
         }
         node.next_level =
             reinterpret_cast<table::PhraseIndex*>(next_level_index);
-      }
-      else {
+      } else {
         auto tail_index = BuildTailIndex(code, *v.second.next_level);
         if (!tail_index) {
           return NULL;
@@ -510,15 +466,14 @@ table::TailIndex* Table::BuildTailIndex(const Code& prefix,
       LOG(ERROR) << "Error creating code sequence; file size: " << file_size();
       return NULL;
     }
-    std::copy(src->code.begin() + Code::kIndexCodeMaxLength,
-              src->code.end(),
+    std::copy(src->code.begin() + Code::kIndexCodeMaxLength, src->code.end(),
               dest.extra_code.begin());
     BuildEntry(*src, &dest.entry);
   }
   return index;
 }
 
-Array<table::Entry>* Table::BuildEntryArray(const DictEntryList& entries) {
+Array<table::Entry>* Table::BuildEntryArray(const ShortDictEntryList& entries) {
   auto array = CreateArray<table::Entry>(entries.size());
   if (!array) {
     return NULL;
@@ -531,7 +486,7 @@ Array<table::Entry>* Table::BuildEntryArray(const DictEntryList& entries) {
   return array;
 }
 
-bool Table::BuildEntryList(const DictEntryList& src,
+bool Table::BuildEntryList(const ShortDictEntryList& src,
                            List<table::Entry>* dest) {
   if (!dest)
     return false;
@@ -549,7 +504,7 @@ bool Table::BuildEntryList(const DictEntryList& src,
   return true;
 }
 
-bool Table::BuildEntry(const DictEntry& dict_entry, table::Entry* entry) {
+bool Table::BuildEntry(const ShortDictEntry& dict_entry, table::Entry* entry) {
   if (!entry)
     return false;
   if (!AddString(dict_entry.text, &entry->text, dict_entry.weight)) {
@@ -570,8 +525,7 @@ bool Table::GetSyllabary(Syllabary* result) {
   return true;
 }
 string Table::GetSyllableById(SyllableId syllable_id) {
-  if (!syllabary_ ||
-      syllable_id < 0 ||
+  if (!syllabary_ || syllable_id < 0 ||
       syllable_id >= static_cast<SyllableId>(syllabary_->size))
     return string();
   return GetString(syllabary_->at[syllable_id]);
@@ -595,11 +549,10 @@ TableAccessor Table::QueryPhrases(const Code& code) {
   return query.Access(-1);
 }
 
-bool Table::Query(const SyllableGraph& syll_graph, size_t start_pos,
+bool Table::Query(const SyllableGraph& syll_graph,
+                  size_t start_pos,
                   TableQueryResult* result) {
-  if (!result ||
-      !index_ ||
-      start_pos >= syll_graph.interpreted_length)
+  if (!result || !index_ || start_pos >= syll_graph.interpreted_length)
     return false;
   result->clear();
   std::queue<pair<size_t, TableQuery>> q;
