@@ -9,32 +9,29 @@
 #define RIME_TABLE_H_
 
 #include <cstring>
-#include <darts.h>
 #include <rime/common.h>
 #include <rime/dict/mapped_file.h>
 #include <rime/dict/vocabulary.h>
 #include <rime/dict/string_table.h>
 
-#define RIME_TABLE_UNION(U, V, A, a, B, b) \
-    struct U { \
-      V value; \
-      const A& a() const { return *reinterpret_cast<const A*>(this); } \
-      const B& b() const { return *reinterpret_cast<const B*>(this); } \
-      A& a() { return *reinterpret_cast<A*>(this); } \
-      B& b() { return *reinterpret_cast<B*>(this); } \
-    }
+#define RIME_TABLE_UNION(U, V, A, a, B, b)                           \
+  struct U {                                                         \
+    V value;                                                         \
+    const A& a() const { return *reinterpret_cast<const A*>(this); } \
+    const B& b() const { return *reinterpret_cast<const B*>(this); } \
+    A& a() { return *reinterpret_cast<A*>(this); }                   \
+    B& b() { return *reinterpret_cast<B*>(this); }                   \
+  }
 
 namespace rime {
 
 namespace table {
 
-//union StringType {
-//  String str;
-//  StringId str_id;
-//};
-RIME_TABLE_UNION(StringType, int32_t,
-                 String, str,
-                 StringId, str_id);
+// union StringType {
+//   String str;
+//   StringId str_id;
+// };
+RIME_TABLE_UNION(StringType, int32_t, String, str, StringId, str_id);
 
 using Syllabary = Array<StringType>;
 
@@ -71,13 +68,11 @@ using TrunkIndex = Array<TrunkIndexNode>;
 
 using TailIndex = Array<LongEntry>;
 
-//union PhraseIndex {
-//  TrunkIndex trunk;
-//  TailIndex tail;
-//};
-RIME_TABLE_UNION(PhraseIndex, Array<char>,
-                 TrunkIndex, trunk,
-                 TailIndex, tail);
+// union PhraseIndex {
+//   TrunkIndex trunk;
+//   TailIndex tail;
+// };
+RIME_TABLE_UNION(PhraseIndex, Array<char>, TrunkIndex, trunk, TailIndex, tail);
 
 using Index = HeadIndex;
 
@@ -101,11 +96,14 @@ struct Metadata {
 class TableAccessor {
  public:
   TableAccessor() = default;
-  TableAccessor(const Code& index_code, const List<table::Entry>* entries,
+  TableAccessor(const Code& index_code,
+                const List<table::Entry>* entries,
                 double credibility = 0.0);
-  TableAccessor(const Code& index_code, const Array<table::Entry>* entries,
+  TableAccessor(const Code& index_code,
+                const Array<table::Entry>* entries,
                 double credibility = 0.0);
-  TableAccessor(const Code& index_code, const table::TailIndex* code_map,
+  TableAccessor(const Code& index_code,
+                const table::TailIndex* code_map,
                 double credibility = 0.0);
 
   RIME_API bool Next();
@@ -130,7 +128,37 @@ class TableAccessor {
 using TableQueryResult = map<int, vector<TableAccessor>>;
 
 struct SyllableGraph;
-class TableQuery;
+
+class TableQuery {
+ public:
+  TableQuery(table::Index* index) : lv1_index_(index) { Reset(); }
+
+  TableAccessor Access(SyllableId syllable_id, double credibility = 0.0) const;
+
+  // down to next level
+  bool Advance(SyllableId syllable_id, double credibility = 0.0);
+
+  // up one level
+  bool Backdate();
+
+  // back to root
+  void Reset();
+
+  size_t level() const { return level_; }
+
+ protected:
+  size_t level_ = 0;
+  Code index_code_;
+  vector<double> credibility_;
+
+ private:
+  bool Walk(SyllableId syllable_id);
+
+  table::HeadIndex* lv1_index_ = nullptr;
+  table::TrunkIndex* lv2_index_ = nullptr;
+  table::TrunkIndex* lv3_index_ = nullptr;
+  table::TailIndex* lv4_index_ = nullptr;
+};
 
 class Table : public MappedFile {
  public:
@@ -154,25 +182,25 @@ class Table : public MappedFile {
   RIME_API string GetEntryText(const table::Entry& entry);
 
   uint32_t dict_file_checksum() const;
+  table::Metadata* metadata() const { return metadata_; }
 
  private:
-  table::Index* BuildIndex(const Vocabulary& vocabulary,
-                           size_t num_syllables);
+  table::Index* BuildIndex(const Vocabulary& vocabulary, size_t num_syllables);
   table::HeadIndex* BuildHeadIndex(const Vocabulary& vocabulary,
                                    size_t num_syllables);
   table::TrunkIndex* BuildTrunkIndex(const Code& prefix,
                                      const Vocabulary& vocabulary);
   table::TailIndex* BuildTailIndex(const Code& prefix,
                                    const Vocabulary& vocabulary);
-  bool BuildPhraseIndex(Code code, const Vocabulary& vocabulary,
+  bool BuildPhraseIndex(Code code,
+                        const Vocabulary& vocabulary,
                         map<string, int>* index_data);
-  Array<table::Entry>* BuildEntryArray(const DictEntryList& entries);
-  bool BuildEntryList(const DictEntryList& src, List<table::Entry>* dest);
-  bool BuildEntry(const DictEntry& dict_entry, table::Entry* entry);
+  Array<table::Entry>* BuildEntryArray(const ShortDictEntryList& entries);
+  bool BuildEntryList(const ShortDictEntryList& src, List<table::Entry>* dest);
+  bool BuildEntry(const ShortDictEntry& dict_entry, table::Entry* entry);
 
   string GetString(const table::StringType& x);
-  bool AddString(const string& src, table::StringType* dest,
-                    double weight);
+  bool AddString(const string& src, table::StringType* dest, double weight);
   bool OnBuildStart();
   bool OnBuildFinish();
   bool OnLoad();
