@@ -25,15 +25,15 @@ bool Matcher::Proceed(Segmentation* segmentation) {
     return true;
   auto match = patterns_.GetMatch(segmentation->input(), *segmentation);
   if (match.found()) {
-    DLOG(INFO) << "match: " << match.tag
-               << " [" << match.start << ", " << match.end << ")";
+    DLOG(INFO) << "match: " << match.tag << " [" << match.start << ", "
+               << match.end << ")";
     while (segmentation->GetCurrentStartPosition() > match.start)
       segmentation->pop_back();
     Segment segment(match.start, match.end);
     segment.tags.insert(match.tag);
     segmentation->AddSegment(segment);
     // terminate this round?
-    //return false;
+    // return false;
   }
   return true;
 }
